
###########################################################################
#
#   Copyright (c) 2001 Erik Enge <erik@thingamy.net>.
#   Copyright (c) 2001 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Id: method.py,v 1.1.1.1 2001/07/04 22:50:33 erik Exp $
# $Source: /cvs/make_product/method.py,v $
__version__='$Revision: 1.1.1.1 $'[11:-2]

"""A collection of classes for creating and maintaining methods within
klass instances.  As you can see, the method class does not know how
to render itself, it needs to subclass the method_rendrer to be able to
do that."""

import types
import string

class basic_method:
    """A basic method"""

    def __init__(self, id, arguments=[], body='',
                 docstring='"""doc string"""', default_indent='    '):
        """Initialize an instance of the class"""
        self.id = id
        self.arguments = arguments
        self.body = body
        self.docstring = docstring
        self.default_indent = default_indent

    def sort_arguments(self):
        """Sort the arguments; non-default before arguments with
        default values"""
        pass

    def get_arguments(self):
        """Return the arguments for the method"""
        self.sort_arguments()
        return self.arguments

class method_rendrer(basic_method):
    """Provides methods for rendering a basic_method instance"""

    def render_arguments(self):
        """Return the arguments-string"""
        arguments = ""
        for argument in self.get_arguments():
            if arguments <> "":
                arguments = arguments + ", "
            if type(argument) == types.ListType:
                arguments = arguments + argument[0] + "=" +\
                            str(argument[1])
            else:
                arguments = arguments + argument
        return arguments

    def render_body(self, indent=''):
        """Return the body of the method"""
        if self.body:
            text = ""
            for line in string.split(self.body, '\n'):
                text = text + indent + line + "\n"
            return text
        else:
            return indent + self.default_indent + "pass\n"

    def render_self(self, indent=''):
        """Render the method instance in text.  This will be
        used when the product class will write itself out to
        the filesystem."""
        text = indent + "def " + self.id + "(" + \
               self.render_arguments() + "):\n"
        text = text + indent + self.default_indent + self.docstring + "\n"
        text = text + self.render_body(indent)
        return text

class method(method_rendrer):
    """doc string"""
    pass

