#!/usr/bin/env python
"""Tests for the method.py-module."""

# $Id: test_method.py,v 1.1.1.1 2001/07/04 22:50:34 erik Exp $
# $Source: /cvs/make_product/tests/test_method.py,v $
__version__ = "$Revision: 1.1.1.1 $"[11:-2]

import unittest
import method

class basic_method_test_case(unittest.TestCase):
    """This test case will test a basic_method instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.method = method.basic_method('id', [], 'body',
                                          '"""docstring"""',
                                          'default_indent')

    def runTest(self):
        """basic_method_test_case"""
        assert self.method.id == 'id', \
               "runTest failed on 'id'"
        assert self.method.arguments == [], \
               "runTest failed on []"
        assert self.method.body == 'body', \
               "runTest failed on 'body'"
        assert self.method.docstring == '"""docstring"""', \
               "runTest failed on 'docstring'"
        assert self.method.default_indent == 'default_indent', \
               "runTest failed on 'default_indent'"

class method_rendrer_test_case(unittest.TestCase):
    """This test case will test a method_rendrer instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.method = method.method_rendrer('id', [], 'body',
                                            '"""docstring"""',
                                            'default_indent')

    def runTest(self):
        """method_rendrer_test_case"""
        assert self.method.id == 'id', \
               "runTest failed on 'id'"
        assert self.method.arguments == [], \
               "runTest failed on []"
        assert self.method.body == 'body', \
               "runTest failed on 'body'"
        assert self.method.docstring == '"""docstring"""', \
               "runTest failed on 'docstring'"
        assert self.method.default_indent == 'default_indent', \
               "runTest failed on 'default_indent'"

class method_rendrer_render_arguments(unittest.TestCase):
    """This test case will test a basic_rendrer instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.method_single = method.method_rendrer(
            'id', ['argument'], 'body', '"""docstring"""', 'default_indent')
        self.method_multiple = method.method_rendrer(
            'id', ['arg1', 'arg2'], 'body', '"""docstring"""', 'default_indent')
        self.method_single_with_default = method.method_rendrer(
            'id', [['argument', '"default"']], 'body',
            '"""docstring"""', 'default_indent')
        self.method_multiple_with_default = method.method_rendrer(
            'id', [['arg1', '"def1"'], ['arg2', '"def2"']], 'body',
            '"""docstring"""', 'default_indent')

    def test_render_arguments_single(self):
        """test_render_arguments_single"""
        assert self.method_single.render_arguments() == 'argument', \
               "test_render_arguments_single failed on render_arguments()"

    def test_render_arguments_single_with_default(self):
        """test_render_arguments_single_with_default"""
        assert self.method_single_with_default.render_arguments() == \
               'argument="default"', \
               "test_render_arguments_single_with_default"\
               "failed on render_arguments()"

    def test_render_arguments_multiple(self):
        """test_render_arguments_multiple"""
        assert self.method_multiple.render_arguments() == 'arg1, arg2', \
               "test_render_arguments_multiple failed on render_arguments()"

    def test_render_arguments_multiple_with_default(self):
        """test_render_arguments_multiple_with_default"""
        assert self.method_multiple_with_default.render_arguments() == \
               'arg1="def1", arg2="def2"', \
               "test_render_arguments_multiple_with_default"\
               "failed on render_arguments()"

class method_rendrer_render_body(unittest.TestCase):
    """This test case will test a method_rendrer instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.method = method.method_rendrer('id', [], 'body',
                                            '"""docstring"""',
                                            'default_indent')

    def runTest(self):
        """method_rendrer_render_body"""
        assert self.method.render_body() == 'body\n', \
               "runTest failed on render_body()"

class method_rendrer_render_self(unittest.TestCase):
    """This test case will test a method_rendrer instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.method = method.method_rendrer('id', [], 'body',
                                            '"""docstring"""',
                                            ' ')

    def runTest(self):
        """method_rendrer_render_self"""
        text = 'def id():\n """docstring"""\nbody\n'
        assert self.method.render_self() == text, \
               "runTest failed on render_self()"

basic_method_suite = unittest.TestSuite()
basic_method_suite.addTest(basic_method_test_case("runTest"))

method_rendrer_suite = unittest.TestSuite()
method_rendrer_suite.addTest(method_rendrer_test_case("runTest"))
method_rendrer_suite.addTest(
    method_rendrer_render_arguments("test_render_arguments_single"))
method_rendrer_suite.addTest(
    method_rendrer_render_arguments("test_render_arguments_single_with_default"))
method_rendrer_suite.addTest(
    method_rendrer_render_arguments("test_render_arguments_multiple"))
method_rendrer_suite.addTest(
    method_rendrer_render_arguments("test_render_arguments_multiple_with_default"))
method_rendrer_suite.addTest(method_rendrer_render_body("runTest"))
method_rendrer_suite.addTest(method_rendrer_render_self("runTest"))

runner = unittest.TextTestRunner()

runner.run(basic_method_suite)
runner.run(method_rendrer_suite)

def test_suite():
    """Return a unittest.TestSuite instance"""
    return unittest.TestSuite((basic_method_suite,
                               rendrer_method_suite,))

if __name__ == '__main__':
    unittest.TextTestRunner().run(test_suite())
