#!/usr/bin/env python
"""Tests for the product.py-module."""

# $Id: test_product.py,v 1.1.1.1 2001/07/04 22:50:34 erik Exp $
# $Source: /cvs/make_product/tests/test_product.py,v $
__version__ = "$Revision: 1.1.1.1 $"[11:-2]

import unittest
import product
import os.path

class basic_product_test_case(unittest.TestCase):
    """This test case will test a basic_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.basic_product = product.basic_product('id')

    def runTest(self):
        """basic_product_test_case"""
        assert self.basic_product.id == 'id', \
               "basic_product_test_case failed on 'id'"

class klass_product_test_case(unittest.TestCase):
    """This test case will test a klass_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.klass_product = product.klass_product('id')

    def runTest(self):
        """klass_product_test_case"""
        assert self.klass_product.id == 'id', \
               "klass_product_test_case failed on 'id'"

class klass_product_list_klasses(unittest.TestCase):
    """This test case will test a klass_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.klass_product = product.klass_product('id')

    def test_list_klasses(self):
        """Check the sequence returned by list_klasses()"""
        assert self.klass_product.list_klasses() == [], \
               "test_list_klasses failed on []"

class klass_product_add_klass(unittest.TestCase):
    """This test case will test a klass_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.klass_product = product.klass_product('id')
        self.klass_product.add_klass('id')

    def test_add_klass(self):
        """Make sure we can add a klass"""
        assert self.klass_product.list_klasses()[0].id == 'id', \
               "test_add_klass failed on 'id'"

class klass_product_remove_klass(unittest.TestCase):
    """This test case will test a klass_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.klass_product = product.klass_product('id')
        self.klass_product.add_klass('id')

    def test_remove_klass(self):
        """Make sure we can remove a klass"""
        self.klass_product.remove_klass('id')
        assert self.klass_product.list_klasses() == [], \
               "test_remove_klass failed on []"

class klass_product_get_klass(unittest.TestCase):
    """This test case will test a klass_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.klass_product = product.klass_product('id')
        self.klass_product.add_klass('id')

    def test_get_klass(self):
        """Make sure we can get a klass"""
        assert self.klass_product.get_klass('id'), \
               "test_get_klass failed on 'id'"

class zope_product_test_case(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/directory/',
                                                 'license', 'docstring',
                                                 'default_indent')
        
    def runTest(self):
        """zope_product_test_case"""
        assert self.zope_product.id == 'id', \
               "zope_product_test_case failed on 'id'"
        assert self.zope_product.directory == '/directory/id/', \
               "zope_product_test_case failed on '/directory/id/'"
        assert self.zope_product.license == 'license', \
               "zope_product_test_case failed on 'license'"
        assert self.zope_product.docstring == 'docstring', \
               "zope_product_test_case failed on 'docstring'"
        assert self.zope_product.default_indent == 'default_indent', \
               "zope_product_test_case failed on 'default_indent'"

class zope_product_add___init__py(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        # Need to make this run on all platforms.  There is probably
        # a nice framework somewhere to operate on files with
        # unittests, but I haven't looked yet :)
        os.mkdir('/tmp/directory')
        os.mkdir(self.zope_product.directory)

    def test_add___init__py(self):
        """Make sure we can add the __init__.py file"""
        self.zope_product._add___init__py()
        assert os.path.isfile(self.zope_product.directory + '__init__.py'), \
               "test_add___init__py failed on '__init__.py'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.remove(self.zope_product.directory + '__init__.py')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_add_versiontxt(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory')
        os.mkdir(self.zope_product.directory)

    def test_add_versiontxt(self):
        """Make sure we can add the version.txt file"""
        self.zope_product._add_versiontxt()
        assert os.path.isfile(self.zope_product.directory + 'version.txt'), \
               "test_add_versiontxt failed on 'version.txt'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.remove(self.zope_product.directory + 'version.txt')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_add_help_directory(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory')
        os.mkdir(self.zope_product.directory)

    def test_add_help_directory(self):
        """Make sure we can add the help/ directory"""
        self.zope_product._add_help_directory()
        assert os.path.isdir(self.zope_product.directory + 'help'), \
               "test_add_help_directory failed on 'help/'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.rmdir(self.zope_product.directory + 'help/')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_add_www_directory(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory')
        os.mkdir(self.zope_product.directory)

    def test_add_www_directory(self):
        """Make sure we can add the www/ directory"""
        self.zope_product._add_www_directory()
        assert os.path.isdir(self.zope_product.directory + 'www'), \
               "test_add_www_directory failed on 'www/'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.rmdir(self.zope_product.directory + 'www/')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_add_dtml_directory(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory')
        os.mkdir(self.zope_product.directory)

    def test_add_dtml_directory(self):
        """Make sure we can add the dtml/ directory"""
        self.zope_product._add_dtml_directory()
        assert os.path.isdir(self.zope_product.directory + 'dtml'), \
               "test_add_dtml_directory failed on 'dtml/'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.rmdir(self.zope_product.directory + 'dtml/')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_write_klasses(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory/')
        os.mkdir('/tmp/directory/id')
        self.zope_product.add_klass('id')
        self.zope_product._write_klasses()

    def test_write_klasses(self):
        """Write one klass to disk"""
        assert os.path.isfile(self.zope_product.directory + 'id.py'), \
               "test_write_klasses failed on 'id.py'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.remove(self.zope_product.directory + 'id.py')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        
class zope_product_write_self(unittest.TestCase):
    """This test case will test a zope_product instance"""

    def setUp(self):
        """Set up necessities for this test"""
        self.zope_product = product.zope_product('id', '/tmp/directory/')
        os.mkdir('/tmp/directory/')
        self.zope_product.write_self()

    def test_write_self(self):
        """Try to write the complete product to disk"""
        assert os.path.isdir(self.zope_product.directory), \
               "test_write_self failed on self.zope_product.directory"
        assert os.path.isdir(self.zope_product.directory + 'dtml'), \
               "test_write_self failed on 'dtml'"
        assert os.path.isdir(self.zope_product.directory + 'www'), \
               "test_write_self failed on 'www'"
        assert os.path.isdir(self.zope_product.directory + 'help'), \
               "test_write_self failed on 'help'"
        assert os.path.isfile(self.zope_product.directory + 'version.txt'), \
               "test_write_self failed on 'version.txt'"
        assert os.path.isfile(self.zope_product.directory + '__init__.py'), \
               "test_write_self failed on '__init__.py'"

    def tearDown(self):
        """Leave things the way we found it"""
        os.rmdir(self.zope_product.directory + 'dtml')
        os.rmdir(self.zope_product.directory + 'www')
        os.rmdir(self.zope_product.directory + 'help')
        os.remove(self.zope_product.directory + 'version.txt')
        os.remove(self.zope_product.directory + '__init__.py')
        os.rmdir(self.zope_product.directory)
        os.rmdir('/tmp/directory')
        

basic_product_suite = unittest.TestSuite()
basic_product_suite.addTest(basic_product_test_case("runTest"))

klass_product_suite = unittest.TestSuite()
klass_product_suite.addTest(klass_product_test_case("runTest"))
klass_product_suite.addTest(klass_product_list_klasses("test_list_klasses"))
klass_product_suite.addTest(klass_product_add_klass("test_add_klass"))
klass_product_suite.addTest(klass_product_remove_klass("test_remove_klass"))
klass_product_suite.addTest(klass_product_get_klass("test_get_klass"))

zope_product_suite = unittest.TestSuite()
zope_product_suite.addTest(zope_product_test_case("runTest"))
zope_product_suite.addTest(zope_product_add___init__py("test_add___init__py"))
zope_product_suite.addTest(zope_product_add_versiontxt("test_add_versiontxt"))
zope_product_suite.addTest(zope_product_add_help_directory("test_add_help_directory"))
zope_product_suite.addTest(zope_product_add_www_directory("test_add_www_directory"))
zope_product_suite.addTest(zope_product_add_dtml_directory("test_add_dtml_directory"))
zope_product_suite.addTest(zope_product_write_klasses("test_write_klasses"))
zope_product_suite.addTest(zope_product_write_self("test_write_self"))

runner = unittest.TextTestRunner()

runner.run(basic_product_suite)
runner.run(klass_product_suite)
runner.run(zope_product_suite)

def test_suite():
    """Return a unittest.TestSuite instance"""
    return unittest.TestSuite((basic_product_suite,
                               klass_product_suite,
                               zope_product_suite,))

if __name__ == '__main__':
    unittest.TextTestRunner().run(test_suite())
